@@ -5,7 +5,7 @@
 """HashingGenerator tests."""
 
 from pathlib import Path
-from typing import Generator, TypedDict
+from typing import Generator, NamedTuple
 
 import aiofiles
 import pytest
@@ -22,7 +22,7 @@ from .testutils import get_test_data_path, hash_file
 pytestmark = [pytest.mark.asyncio]
 
 
-class TypingHashingGenerator(TypedDict):
+class TypingHashingGenerator(NamedTuple):
     # pylint: disable=missing-class-docstring
     hashing_generator: HashingGenerator
     path: Path
@@ -50,7 +50,9 @@ async def hashing_generator_async(
 ) -> Generator[TypingHashingGenerator, None, None]:
     """Provides hashing generator instance and associated data."""
     async with aiofiles.open(manifest_name, mode="r+b") as file:
-        yield {"hashing_generator": HashingGenerator(file), "path": manifest_name}
+        yield TypingHashingGenerator(
+            hashing_generator=HashingGenerator(file), path=manifest_name
+        )
 
 
 @pytest.fixture()
@@ -59,27 +61,27 @@ def hashing_generator_sync(
 ) -> Generator[TypingHashingGenerator, None, None]:
     """Provides hashing generator instance and associated data."""
     with manifest_name.open("r+b") as file:
-        yield {
-            "hashing_generator": HashingGenerator(file, file_is_async=False),
-            "path": manifest_name,
-        }
+        yield TypingHashingGenerator(
+            hashing_generator=HashingGenerator(file, file_is_async=False),
+            path=manifest_name,
+        )
 
 
 async def test_get_digest_async(
     hashing_generator_async: TypingHashingGenerator,
 ):
     """Test digest value calculation (async)."""
-    async for _ in hashing_generator_async["hashing_generator"]:
+    async for _ in hashing_generator_async.hashing_generator:
         pass
-    digest = await hash_file(hashing_generator_async["path"])
-    assert hashing_generator_async["hashing_generator"].get_digest() == digest
+    digest = await hash_file(hashing_generator_async.path)
+    assert hashing_generator_async.hashing_generator.get_digest() == digest
 
 
 async def test_get_digest_sync(
     hashing_generator_sync: TypingHashingGenerator,
 ):
     """Test digest value calculation (sync)."""
-    async for _ in hashing_generator_sync["hashing_generator"]:
+    async for _ in hashing_generator_sync.hashing_generator:
         pass
-    digest = await hash_file(hashing_generator_sync["path"])
-    assert hashing_generator_sync["hashing_generator"].get_digest() == digest
+    digest = await hash_file(hashing_generator_sync.path)
+    assert hashing_generator_sync.hashing_generator.get_digest() == digest
